@@ -10,6 +10,7 @@ from pullenti.ner.SourceOfAnalysis import SourceOfAnalysis
 from pullenti.ner.keyword.KeywordAnalyzer import KeywordAnalyzer
 from pullenti.ner.keyword.KeywordReferent import KeywordReferent
 from pymorphy2 import MorphAnalyzer
+import emoji
 
 from srsparser import configs
 from srsparser.sections_tree import SectionsTree
@@ -208,9 +209,10 @@ class NLProcessor:
         :param text: processing text.
         :return: keyword list.
         """
+        text_without_emoji = emoji.get_emoji_regexp().sub(u'', text)
         keywords: List[str] = []
         with ProcessorService.create_specific_processor(KeywordAnalyzer.ANALYZER_NAME) as proc:
-            ar = proc.process(SourceOfAnalysis(text), None, None)
+            ar = proc.process(SourceOfAnalysis(text_without_emoji), None, None)
             for e0_ in ar.entities:
                 if isinstance(e0_, KeywordReferent):
                     keywords.append(e0_.to_string(short_variant=True))
